@@ -21,13 +21,13 @@ import readrss
 import re
 import time
 from pprint import pprint
-from tinyurl import tiny
+from shortener import services
 from parsetime import parsetime
 from httplib import BadStatusLine
 from urllib2 import HTTPError
 
 class Feed2Twitter(object):
-    def __init__(self,  url, username, passwd, mode='title', items = 5):
+    def __init__(self,  url, username, passwd, mode='title', items = 5, shortener='tinyurl'):
         self.mode = mode
         self.url = url
         self.items = items
@@ -37,9 +37,10 @@ class Feed2Twitter(object):
         self.twApi = twitter.Api(username=self.username, password=self.passwd)
         self.set_attr_headers()
         self.rss = readrss.parse(url)
+        self.shortener = services[shortener]()
     
     def set_attr_headers(self):
-        self.twApi.SetXTwitterHeaders('feed2twitter', 'http://www. assembla.com/spaces/feed2twitter', self.version)    
+        self.twApi.SetXTwitterHeaders('feed2twitter', 'http://www.assembla.com/spaces/feed2twitter', self.version)    
 
     def strip_tags(self,value):
         "Return the given HTML with all tags stripped."
@@ -50,7 +51,7 @@ class Feed2Twitter(object):
         oldItems=pItems=0
         for it in list(items):
             if self.mode == 'title':
-                txt=it["title"][0:114] +" "+tiny(it["link"])
+                txt=it["title"][0:114] +" "+self.shortener.short(it["link"])
             elif self.mode == 'text':
                 try:
                     txt = self.strip_tags(it.content[0].value)[0:140]
@@ -105,39 +106,53 @@ def PostUpdate(self, text):
 
 #setattr(twitter.Api, PostUpdate.__name__, PostUpdate)
 
-def update():
-    opt = Options()
-    options = opt.parse()
-    conf = ConfigParser()
-    if options.sample_config:
-        from pkg_resources import resource_string
-        foo_config = resource_string(__name__, '../docs/default.cfg.sample')
-        print(foo_config)
-        sys.exit(1)
-    try:
-        fd =  open(options.config_filename, 'r')
-    except IOError:
-        print >>sys.stderr, "File %s not found" % configfile
-        sys.exit(2)
-    conf.readfp(fd)
+def update(**kwargs):
+    if not kwargs:
+        opt = Options()
+        options = opt.parse()
+        conf = ConfigParser()
+        if options.sample_config:
+            from pkg_resources import resource_string
+            foo_config = resource_string(__name__, '../docs/default.cfg.sample')
+            print(foo_config)
+            sys.exit(1)
+        try:
+            fd =  open(options.config_filename, 'r')
+        except IOError:
+            print >>sys.stderr, "File %s not found" % configfile
+            sys.exit(2)
+            conf.readfp(fd)
 
+            url = conf.get("global", "url").strip()
+            username = conf.get("global", "username").strip()
+            password = conf.get("global", "password").strip()
+            mode = conf.get("global","mode").strip()
+            try:
+                items = int(conf.get("global","items").strip())
+            except NoOptionError:
+                items = 5
 
-    url = conf.get("global", "url").strip()
-    username = conf.get("global", "username").strip()
-    password = conf.get("global", "password").strip()
-    mode = conf.get("global","mode").strip()
-    try:
-        items = int(conf.get("global","items").strip())
-    except NoOptionError:
+            try:
+                interval = parsetime(conf.get("global","interval").strip())
+            except:
+                print('Error in the interval setting')
+                sys.exit(1)
+
+            try:
+                shortener = conf.get('global','shortener').strip()
+            except NoOptionError:
+                shortener = 'tinyurl'
+    else:
+        url = kwargs['url']
+        username = kwargs['username']
+        password = kwargs['password']
+        mode = kwargs['mode']
         items = 5
-    try:
-        interval = parsetime(conf.get("global","interval").strip())
-    except:
-        print('Error in the interval setting')
-        sys.exit(1)
-    print(interval)
+        shortener = kwargs['shortener']
+        interval = parsetime('00:05')
+
     while True:
-        feed2tw = Feed2Twitter(url, username, password, mode, items)
+        feed2tw = Feed2Twitter(url, username, password, mode, items, shortener)
         from distutils import version
         if version.LooseVersion(twitter.__version__) > version.LooseVersion('0.5'):
             feed2tw.twApi.SetSource('feed2twitter')
@@ -146,5 +161,5 @@ def update():
         feed2tw.update()
         time.sleep(interval)
 
-__version__ = '0.6.4'
+__version__ = '0.6.5'
 
